/* Includes ***************************************************************/

#include "SoftCursor.h"

/* Functions **************************************************************/

void HardwareCursor()
{
	SystemParametersInfo(SPI_SETMOUSETRAILS, 0, NULL, SPIF_UPDATEINIFILE);
}

/**************************************************************************/

void SoftwareCursor()
{
	SystemParametersInfo(SPI_SETMOUSETRAILS, -1, NULL, SPIF_UPDATEINIFILE);
}

/**************************************************************************/

BOOL CALLBACK DialogProc(HWND dialog, UINT message, WPARAM wParam, LPARAM lParam)
{
	int param;

	switch (message)
	{
		case WM_INITDIALOG:
			SystemParametersInfo(SPI_GETMOUSETRAILS, 0, &param, 0);

			if (param == 0 || param == 1)
				CheckDlgButton(dialog, IDC_HARDWARE, TRUE);
			else if (param < 0)
				CheckDlgButton(dialog, IDC_SOFTWARE, TRUE);

			return TRUE;

		case WM_COMMAND:
			switch (wParam)
			{
				case IDC_HARDWARE:
					HardwareCursor();
					return TRUE;

				case IDC_SOFTWARE:
					SoftwareCursor();
					return TRUE;
			}

			return FALSE;

		case WM_CLOSE:
			EndDialog(dialog, 0);
			return TRUE;
	}

	return FALSE;
}

/**************************************************************************/

BOOL ProcessCommand(LPTSTR cmdLine)
{
	if (cmdLine[0] != _T('-') && cmdLine[0] != _T('/'))
		return FALSE;

	if (cmdLine[2] != 0)
		return FALSE;

	switch (cmdLine[1])
	{
		case _T('H'):
		case _T('h'):
			HardwareCursor();
			return TRUE;

		case _T('S'):
		case _T('s'):
			SoftwareCursor();
			return TRUE;
	}

	return FALSE;
}

/* Main *******************************************************************/

int WINAPI _tWinMain(HINSTANCE instance, HINSTANCE prevInstance, LPTSTR cmdLine, int cmdShow)
{
	if (ProcessCommand(cmdLine))
		return 0;

	DialogBox(instance, _T("IDD_DIALOG"), NULL, DialogProc);
	return 0;
}

/**************************************************************************/
